Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EnvSpecExpansion ¶
type EnvSpecExpansion interface{}
type EtV1alpha1Client ¶
type EtV1alpha1Client struct {
// contains filtered or unexported fields
}
EtV1alpha1Client is used to interact with features provided by the et group.
func New ¶
func New(c rest.Interface) *EtV1alpha1Client
New creates a new EtV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*EtV1alpha1Client, error)
NewForConfig creates a new EtV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *EtV1alpha1Client
NewForConfigOrDie creates a new EtV1alpha1Client for the given config and panics if there is an error in the config.
func (*EtV1alpha1Client) RESTClient ¶
func (c *EtV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*EtV1alpha1Client) TrainingJobs ¶
func (c *EtV1alpha1Client) TrainingJobs(namespace string) TrainingJobInterface
type EtV1alpha1Interface ¶
type EtV1alpha1Interface interface {
RESTClient() rest.Interface
TrainingJobsGetter
}
type ScaleInSpecExpansion ¶
type ScaleInSpecExpansion interface{}
type TrainingJobExpansion ¶
type TrainingJobExpansion interface{}
type TrainingJobInterface ¶
type TrainingJobInterface interface {
Create(ctx context.Context, trainingJob *v1alpha1.TrainingJob, opts v1.CreateOptions) (*v1alpha1.TrainingJob, error)
Update(ctx context.Context, trainingJob *v1alpha1.TrainingJob, opts v1.UpdateOptions) (*v1alpha1.TrainingJob, error)
UpdateStatus(ctx context.Context, trainingJob *v1alpha1.TrainingJob, opts v1.UpdateOptions) (*v1alpha1.TrainingJob, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.TrainingJob, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.TrainingJobList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.TrainingJob, err error)
TrainingJobExpansion
}
TrainingJobInterface has methods to work with TrainingJob resources.
type TrainingJobSpecExpansion ¶
type TrainingJobSpecExpansion interface{}
type TrainingJobsGetter ¶
type TrainingJobsGetter interface {
TrainingJobs(namespace string) TrainingJobInterface
}
TrainingJobsGetter has a method to return a TrainingJobInterface. A group's client should implement this interface.